﻿using System.Windows;
using AttsInjectorHelper.Enums;
using ImageNexus.BenScharbach.Common.AttributesCodeInjector.AttsException;
using ImageNexus.BenScharbach.Common.AttributesCodeInjector.AttsUnity;
using ImageNexus.BenScharbach.Common.AttsInjectorHelper;
using ImageNexus.BenScharbach.Common.MEFLoggerInterfaces.Enums;
using Microsoft.Practices.EnterpriseLibrary.Common.Configuration;
using Microsoft.Practices.EnterpriseLibrary.Logging;
using PostSharp.Extensibility;

// Note: Remember to always add the categories using 'AttsUnityContainer.AddLogEntryCategoryCollection'
[assembly: OnMefLogger(LoggerTypeEnum.EntLibLogger, "EverNoteDropperConsole", LogPropertyCalls = true,
        LoggerVerbosity = LoggerVerbosityEnum.LogEntry | LoggerVerbosityEnum.LogExceptions,
        TraceLoggerOutputPath = @"EverNoteDropper\DummyOutput.txt", WpfLogWindowInstanceId = 1, AttributeTargetTypes = "ImageNexus.BenScharbach.Utilities.EverNoteDropper.*",
        AttributeTargetTypeAttributes = MulticastAttributes.Public | MulticastAttributes.Abstract | MulticastAttributes.Internal |
        MulticastAttributes.Protected | MulticastAttributes.Private | MulticastAttributes.Virtual)]

namespace ImageNexus.BenScharbach.Utilities.EverNoteDropper
{
    /// <summary>
    /// Interaction logic for App.xaml
    /// </summary>
    public partial class App : Application
    {
        private void Application_Startup(object sender, StartupEventArgs e)
        {
            // Add the Enterprise-Logger "Category" listeners for all PostSharp attributes to use
            AttsUnityContainer.AddLogEntryCategoryCollection(new string[] { "EverNoteDropper-General", "EverNoteDropper-Errors" });
        }

        [OnCatchAllExceptionHandling(false, null, null)]
        private void Application_DispatcherUnhandledException(object sender, System.Windows.Threading.DispatcherUnhandledExceptionEventArgs e)
        {
            MessageBox.Show(
               @"The application ran into a serious error!  Please look at the trace logs located at \\programdata\image-nexus\",
               "App Error", MessageBoxButton.OK, MessageBoxImage.Error);

            var logWriter = EnterpriseLibraryContainer.Current.GetInstance<LogWriter>();
            var message = string.Format("App.Dispatcher caught an error => {0} ", e.Exception.Message);
            var logEntry = new LogEntry { EventId = 456, Priority = 2, Message = message };
            logEntry.Categories.Add("EverNoteDropper-Errors");
            logWriter.Write(logEntry);
        }
    }
}
